@@ -36,7 +36,7 @@
 
 (eask-start
   (eask-defvc< 27 (eask-pkg-init))  ; XXX: remove this after we drop 26.x
-  (if-let ((names (eask-args)))
+  (if-let* ((names (eask-args)))
       ;; If package [name..] are specified, we try to install it
       (eask-reinstall--packages names)
     (if-let* ((name (intern (eask-guess-package-name)))
